# Obsidian Parser

A small library for a Obsidian Vaults to parse its content. One example is to prepare the content to publishing with static site generators, Hugo as an example.

## Installation

```bash
pip install obsidian-parser
```

## Get started

How to multiply one number by another with this lib:

```python
# Import Multiplication from your library
from obsidian_parser import Multiplication

# Instantiate a Multiplication object
multiplication = Multiplication(2)

# Call the multiply method
print(multiplication.multiply(5))
```
